// functions is a collection of functions that encapsulate the logic to run the question. It is in the global scope
var functions = function(){

    var selectedTarget = null;
    var correctTarget = "Selector5";

    var selectedClass = "selected";

    var submitted = false;
    var score = 0;



    // this function will remove the selected class from all selected elements
    // PRIVATE
    var removeSelection = function(){
        var selected = document.getElementsByClassName(selectedClass);
        
        for(var i = selected.length-1; i >= 0; i--){ // decrementing the counter because the array may be modified as the class is removed
            selected[i].className = selected[i].className.replace(selectedClass, ''); // remove the selected class from the element
        }
    }


    // this function will add a selected class to the given element
    // PRIVATE
    var addSelection = function(target){

        if(target.className.indexOf(selectedClass) > -1){
            return; // the element is alread selected
        }
        else{
            target.className += " " + selectedClass;
        }
    }


    // outlines the correct answer in green
    // PRIVATE
    var showCorrectAnswer = function(){
        var correctElement = document.getElementById(correctTarget);
        correctElement.style.borderColor = "green";
        correctElement.style.borderWidth = 3;
        correctElement.style.borderStyle = "solid";

        if(selectedTarget && selectedTarget.id != correctElement.id){
            selectedTarget.style.borderColor = "red";
            selectedTarget.style.borderWidth = 3;
            selectedTarget.style.borderStyle = "solid";
        }
            
    };


    // shows the correct or incorrect feedback depending on the user's selection
    // PRIVATE
    var showFeedback = function(){
        var correct = isCorrect();

        if(correct){
            // show the correct feedback
            document.getElementById("correctFeedback").className = "";
        }
        else{
            // show the incorrect feedback
            document.getElementById("incorrectFeedback").className = "";
        }
    };


    // shows the next button and hides the submit button
    // PRIVATE
    var showNext = function(){
        var submitButton = document.getElementById("submit");
        var nextButton = document.getElementById("goNext");

        // hide the submit button
        submitButton.className = "hidden";

        // show the next button
        nextButton.className = "";
    }



    // this function will return a boolean value to determine if the answer was answered correctly or not
    // PRIVATE
    var isCorrect = function(){
        // use !! to ensure the returned value is a boolean
        return !!(selectedTarget && selectedTarget.id == correctTarget);
    }


    // this function is called when the question is submitted
    // PUBLIC
    var submit = function(){
        var correct = isCorrect();
        score = correct? 100: 0; // score is in percent, 0-100 (in this case the question is either correct or incorrect, so there's no partial score available)
        
        var selectedId = selectedTarget? selectedTarget.id: null;

        showNext();
        showFeedback();
        if(top.contentApi){
            top.contentApi.setData(
                "page_" + top.contentApi.getPageID() + "_hotspotQuestion", // A unique identifier is needed to save the data - I used the current pageID from the contentApi to ensure this is unique
                selectedId // The value to store
            );
        }

        submitted = true; // to ensure that the user can't try to make any more selections after they click submit
    };


    // called when the next button is clicked
    // PUBLIC
    var nextClicked = function(){
        if(!top.contentApi){return;}
        if(!submitted){
            top.contentApi.contentGoNext(); // if the question hasn't been submitted then just go to the next page
        }
        else{
            // if the submit button has been clicked and the question hasn't been submitted then submit the question and allow that to handle the navigation
            top.contentApi.submitQuestion(
                score // the percent that the user got correct on this question
            );
        }

    };


    // called when any of the selection areas have been clicked
    // PUBLIC
    var clickHandler = function(e){
        if(submitted){
            return; // if the question has already been submitted then there's nothing to do here
        }

        selectedTarget = e.target;
        removeSelection();
        addSelection(selectedTarget);
    }


    // gets called on initialization, sets up for review if in a review
    // PUBLIC
    var init = function(){
        if(top.contentApi && top.contentApi.inReview()){ // there's nothing to initialize outside of review
            submited = true;
            var selectedId = top.contentApi.getData(
                "page_" + top.contentApi.getPageID() + "_hotspotQuestion" // A unique identifier is needed to get the data - I used the current pageID from the contentApi to ensure this is unique
            );

            selectedTarget = document.getElementById(selectedId);

            // in review we need to show the next button so the user can navigate, show the correct answer, and show the feedback text
            showNext();
            showCorrectAnswer();
            showFeedback();
        }
    }


    // return public functions
    return{
        init: init,
        submit: submit,
        clickHandler: clickHandler,
        next: nextClicked
    };
}();